


'''
	import legumes.recipe_with_goals.formulate as formulate_recipe_with_goals
	formulate_recipe_with_goals.beautifully ([
		[ retrieve_supp ("coated tablets/multivitamin_276336.JSON"), 10 ]
	])
'''

'''
	fake data: {
		"info": {
			"includes": [],
			"names": [
				"protein"
			],
			"region": 1
		},
		"measures": {
			"mass + mass equivalents": {
				"per recipe": {
					"grams": {
						"fraction string": "65193545255861875341/11258999068426240"
					}
				},
				"portion of grove": {
					"fraction string": "1303870905117237506820000/3661863958435401439007099"
				}
			}
		},
		"goals": {
			"days of nutrients per recipe": {
				"fraction string": "123/4"
			}
		}
	}
'''



import legumes.goals.human.FDA as human_FDA_goal

import apoplast.shows.ingredient_scan_recipe.formulate as formulate_recipe

def beautifully (ingredients):
	recipe = formulate_recipe.adroitly (ingredients)
	
	
	
	return;
	
	
	
	
	
	
	
	
	
	# goal = human_FDA_goal.retrieve ()



'''
	import legumes.goals.human.FDA as human_FDA_goal
	goal = human_FDA_goal.retrieve ()
'''

'''
	https://ods.od.nih.gov/HealthInformation/nutrientrecommendations.aspx
'''

'''
	https://www.fda.gov/food/nutrition-facts-label/daily-value-nutrition-and-supplement-facts-labels
'''

#
#	 of 4 or more years
#

def retrieve ():
    return {
		"label": "FDA goals for average adult humans",
		"cautions": [
			"These guidelines have not been checked by any high status nutritionists.",
			"Please consult with your actual physician or nutritionist also."
		],
		
        "ingredients": [
            {
                "goal": [ "2000", "kcal" ],
                "labels": [ "calories" ]
            },
		],
        
        "limiters": [
            {
                "includes": [
                    "human"
                ],
                "label": "species"
            },
            {
                "includes": [
                    [
                        "4",
                        "eternity"
                    ]
                ],
                "kind": "slider--integer",
                "label": "age"
            },
            {
                "includes": [
                    "pregnant",
                    "breast feeding"
                ],
                "label": "exclusions"
            }
        ],
		
        "sources": [
            "https://www.fda.gov/food/new-nutrition-facts-label/daily-value-new-nutrition-and-supplement-facts-labels",
            "https://www.fda.gov/media/99069/download",
            "https://www.fda.gov/media/99059/download"
        ]
    }
